==> pixi-0.50.0-crates.tar.xz: cargo_home/gentoo/rattler_pty-0.2.4/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.4](https://github.com/conda/rattler/compare/rattler_pty-v0.2.3...rattler_pty-v0.2.4) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [0.2.3](https://github.com/conda/rattler/compare/rattler_pty-v0.2.2...rattler_pty-v0.2.3) - 2025-06-26

### Other

- *(ci)* Update Rust crate nix to 0.30.0 ([#1439](https://github.com/conda/rattler/pull/1439))

## [0.2.2](https://github.com/conda/rattler/compare/rattler_pty-v0.2.1...rattler_pty-v0.2.2) - 2025-06-23

### Other

- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [0.2.1](https://github.com/conda/rattler/compare/rattler_pty-v0.2.0...rattler_pty-v0.2.1) - 2025-05-16

### Other

- update dependencies ([#1126](https://github.com/conda/rattler/pull/1126))

## [0.2.0](https://github.com/conda/rattler/compare/rattler_pty-v0.1.1...rattler_pty-v0.2.0) - 2025-04-10

### Added

- Add start_unix_shell in Activator (2/n) ([#1180](https://github.com/conda/rattler/pull/1180))

## [0.1.1](https://github.com/conda/rattler/compare/rattler_pty-v0.1.0...rattler_pty-v0.1.1) - 2025-04-04

### Other

- add the remove_from_backup function and update the prefix ([#1155](https://github.com/conda/rattler/pull/1155))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

==> pixi-0.55.0-crates.tar.xz: cargo_home/gentoo/rattler_pty-0.2.6/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.6](https://github.com/conda/rattler/compare/rattler_pty-v0.2.5...rattler_pty-v0.2.6) - 2025-07-23

### Other

- *(rattler_pty)* fix `needless_continue` lint ([#1547](https://github.com/conda/rattler/pull/1547))

## [0.2.5](https://github.com/conda/rattler/compare/rattler_pty-v0.2.4...rattler_pty-v0.2.5) - 2025-07-21

### Other

- bump rust 1.88.0 ([#1536](https://github.com/conda/rattler/pull/1536))

## [0.2.4](https://github.com/conda/rattler/compare/rattler_pty-v0.2.3...rattler_pty-v0.2.4) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [0.2.3](https://github.com/conda/rattler/compare/rattler_pty-v0.2.2...rattler_pty-v0.2.3) - 2025-06-26

### Other

- *(ci)* Update Rust crate nix to 0.30.0 ([#1439](https://github.com/conda/rattler/pull/1439))

## [0.2.2](https://github.com/conda/rattler/compare/rattler_pty-v0.2.1...rattler_pty-v0.2.2) - 2025-06-23

### Other

- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [0.2.1](https://github.com/conda/rattler/compare/rattler_pty-v0.2.0...rattler_pty-v0.2.1) - 2025-05-16

### Other

- update dependencies ([#1126](https://github.com/conda/rattler/pull/1126))

## [0.2.0](https://github.com/conda/rattler/compare/rattler_pty-v0.1.1...rattler_pty-v0.2.0) - 2025-04-10

### Added

- Add start_unix_shell in Activator (2/n) ([#1180](https://github.com/conda/rattler/pull/1180))

## [0.1.1](https://github.com/conda/rattler/compare/rattler_pty-v0.1.0...rattler_pty-v0.1.1) - 2025-04-04

### Other

- add the remove_from_backup function and update the prefix ([#1155](https://github.com/conda/rattler/pull/1155))
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).
